import { useEffect, useMemo } from "react";
import { atom as $, useAtom, Atom, PrimitiveAtom, useAtomValue, useSetAtom, } from 'jotai';
import { baseUrl } from "./App";
import { useCommand } from "./util";

type PickerInput = { 
  $options?:PrimitiveAtom<Array<string>>, 
  $isLoading?:PrimitiveAtom<boolean>, 
  $selectedOptionValue?:PrimitiveAtom<string>, 
  $url:Atom<string>, 
  $isEnabled?:Atom<boolean>
};
export function Picker({ 
    $url, 
    $options        = useMemo(()=>$([]),  []), 
    $isLoading      = useMemo(()=>$(true),[]), 
    $isEnabled      = useMemo(()=>$(true),[]), 
    $selectedOptionValue = useMemo(()=>$(''),  [])
  }: PickerInput){
  const url = useAtomValue($url);
  const options = useAtomValue($options);
  const isLoading = useAtomValue($isLoading);
  const [selectedOptionValue, setSelectedOptionValue] = useAtom($selectedOptionValue);
  const isEnabled = useAtomValue($isEnabled);

  const handleFetchedOptions = useCommand((get,set,options)=>{
    set($options, options);
    set($isLoading, false);
  }, [$options, $isLoading]);

  useEffect(()=>{
    if(isEnabled){
      fetch(url)
      .then(x=>x.json())
      .catch((err)=>['AAPL', 'MSFT', 'GOOG'])
      .then(handleFetchedOptions)
    }
  },[url, isEnabled])
  
  return (
    <div>
      {isLoading
      ?
      <span>Loading...</span>
      :
      <select value={selectedOptionValue} onChange={(e)=>{ setSelectedOptionValue(e.target.value); }}>
        <option key="" value=""></option>
        {options.map((date)=>
          <option key={date} value={date}>{date}</option>
        )}
      </select>
      }
    </div>
  );
}